@@ -133,6 +133,7 @@ class DropConstraintOp(MigrateOperation):
         constraint_name: Optional[sqla_compat._ConstraintNameDefined],
         table_name: str,
         type_: Optional[str] = None,
+        *,
         schema: Optional[str] = None,
         _reverse: Optional[AddConstraintOp] = None,
     ) -> None:
@@ -173,9 +174,7 @@ class DropConstraintOp(MigrateOperation):
             _reverse=AddConstraintOp.from_constraint(constraint),
         )
 
-    def to_constraint(
-        self,
-    ) -> Constraint:
+    def to_constraint(self) -> Constraint:
 
         if self._reverse is not None:
             constraint = self._reverse.to_constraint()
@@ -198,8 +197,9 @@ class DropConstraintOp(MigrateOperation):
         constraint_name: str,
         table_name: str,
         type_: Optional[str] = None,
+        *,
         schema: Optional[str] = None,
-    ) -> Optional[Table]:
+    ) -> None:
         r"""Drop a constraint of the given name, typically via DROP CONSTRAINT.
 
         :param constraint_name: name of the constraint.
@@ -258,6 +258,7 @@ class CreatePrimaryKeyOp(AddConstraintOp):
         constraint_name: Optional[sqla_compat._ConstraintNameDefined],
         table_name: str,
         columns: Sequence[str],
+        *,
         schema: Optional[str] = None,
         **kw: Any,
     ) -> None:
@@ -299,18 +300,17 @@ class CreatePrimaryKeyOp(AddConstraintOp):
         constraint_name: Optional[str],
         table_name: str,
         columns: List[str],
+        *,
         schema: Optional[str] = None,
-    ) -> Optional[Table]:
+    ) -> None:
         """Issue a "create primary key" instruction using the current
         migration context.
 
         e.g.::
 
             from alembic import op
-            op.create_primary_key(
-                        "pk_my_table", "my_table",
-                        ["id", "version"]
-                    )
+
+            op.create_primary_key("pk_my_table", "my_table", ["id", "version"])
 
         This internally generates a :class:`~sqlalchemy.schema.Table` object
         containing the necessary columns, then generates a new
@@ -337,7 +337,7 @@ class CreatePrimaryKeyOp(AddConstraintOp):
          :class:`~sqlalchemy.sql.elements.quoted_name`.
 
         """
-        op = cls(constraint_name, table_name, columns, schema)
+        op = cls(constraint_name, table_name, columns, schema=schema)
         return operations.invoke(op)
 
     @classmethod
@@ -382,6 +382,7 @@ class CreateUniqueConstraintOp(AddConstraintOp):
         constraint_name: Optional[sqla_compat._ConstraintNameDefined],
         table_name: str,
         columns: Sequence[str],
+        *,
         schema: Optional[str] = None,
         **kw: Any,
     ) -> None:
@@ -433,6 +434,7 @@ class CreateUniqueConstraintOp(AddConstraintOp):
         constraint_name: Optional[str],
         table_name: str,
         columns: Sequence[str],
+        *,
         schema: Optional[str] = None,
         **kw: Any,
     ) -> Any:
@@ -593,6 +595,7 @@ class CreateForeignKeyOp(AddConstraintOp):
         referent_table: str,
         local_cols: List[str],
         remote_cols: List[str],
+        *,
         onupdate: Optional[str] = None,
         ondelete: Optional[str] = None,
         deferrable: Optional[bool] = None,
@@ -601,16 +604,21 @@ class CreateForeignKeyOp(AddConstraintOp):
         source_schema: Optional[str] = None,
         referent_schema: Optional[str] = None,
         **dialect_kw: Any,
-    ) -> Optional[Table]:
+    ) -> None:
         """Issue a "create foreign key" instruction using the
         current migration context.
 
         e.g.::
 
             from alembic import op
+
             op.create_foreign_key(
-                        "fk_user_address", "address",
-                        "user", ["user_id"], ["id"])
+                "fk_user_address",
+                "address",
+                "user",
+                ["user_id"],
+                ["id"],
+            )
 
         This internally generates a :class:`~sqlalchemy.schema.Table` object
         containing the necessary columns, then generates a new
@@ -672,12 +680,13 @@ class CreateForeignKeyOp(AddConstraintOp):
         referent_table: str,
         local_cols: List[str],
         remote_cols: List[str],
+        *,
         referent_schema: Optional[str] = None,
-        onupdate: None = None,
-        ondelete: None = None,
-        deferrable: None = None,
-        initially: None = None,
-        match: None = None,
+        onupdate: Optional[str] = None,
+        ondelete: Optional[str] = None,
+        deferrable: Optional[bool] = None,
+        initially: Optional[str] = None,
+        match: Optional[str] = None,
         **dialect_kw: Any,
     ) -> None:
         """Issue a "create foreign key" instruction using the
@@ -690,8 +699,11 @@ class CreateForeignKeyOp(AddConstraintOp):
 
             with batch_alter_table("address") as batch_op:
                 batch_op.create_foreign_key(
-                            "fk_user_address",
-                            "user", ["user_id"], ["id"])
+                    "fk_user_address",
+                    "user",
+                    ["user_id"],
+                    ["id"],
+                )
 
         .. seealso::
 
@@ -733,6 +745,7 @@ class CreateCheckConstraintOp(AddConstraintOp):
         constraint_name: Optional[sqla_compat._ConstraintNameDefined],
         table_name: str,
         condition: Union[str, TextClause, ColumnElement[Any]],
+        *,
         schema: Optional[str] = None,
         **kw: Any,
     ) -> None:
@@ -775,10 +788,11 @@ class CreateCheckConstraintOp(AddConstraintOp):
         operations: Operations,
         constraint_name: Optional[str],
         table_name: str,
-        condition: Union[str, BinaryExpression],
+        condition: Union[str, BinaryExpression, TextClause],
+        *,
         schema: Optional[str] = None,
         **kw: Any,
-    ) -> Optional[Table]:
+    ) -> None:
         """Issue a "create check constraint" instruction using the
         current migration context.
 
@@ -790,7 +804,7 @@ class CreateCheckConstraintOp(AddConstraintOp):
             op.create_check_constraint(
                 "ck_user_name_len",
                 "user",
-                func.len(column('name')) > 5
+                func.len(column("name")) > 5,
             )
 
         CHECK constraints are usually against a SQL expression, so ad-hoc
@@ -827,9 +841,9 @@ class CreateCheckConstraintOp(AddConstraintOp):
         cls,
         operations: BatchOperations,
         constraint_name: str,
-        condition: TextClause,
+        condition: Union[str, BinaryExpression, TextClause],
         **kw: Any,
-    ) -> Optional[Table]:
+    ) -> None:
         """Issue a "create check constraint" instruction using the
         current batch migration context.
 
@@ -861,6 +875,7 @@ class CreateIndexOp(MigrateOperation):
         index_name: Optional[str],
         table_name: str,
         columns: Sequence[Union[str, TextClause, ColumnElement[Any]]],
+        *,
         schema: Optional[str] = None,
         unique: bool = False,
         **kw: Any,
@@ -912,24 +927,27 @@ class CreateIndexOp(MigrateOperation):
         index_name: Optional[str],
         table_name: str,
         columns: Sequence[Union[str, TextClause, Function[Any]]],
+        *,
         schema: Optional[str] = None,
         unique: bool = False,
         **kw: Any,
-    ) -> Optional[Table]:
+    ) -> None:
         r"""Issue a "create index" instruction using the current
         migration context.
 
         e.g.::
 
             from alembic import op
-            op.create_index('ik_test', 't1', ['foo', 'bar'])
+
+            op.create_index("ik_test", "t1", ["foo", "bar"])
 
         Functional indexes can be produced by using the
         :func:`sqlalchemy.sql.expression.text` construct::
 
             from alembic import op
             from sqlalchemy import text
-            op.create_index('ik_test', 't1', [text('lower(foo)')])
+
+            op.create_index("ik_test", "t1", [text("lower(foo)")])
 
         :param index_name: name of the index.
         :param table_name: name of the owning table.
@@ -969,7 +987,7 @@ class CreateIndexOp(MigrateOperation):
         index_name: str,
         columns: List[str],
         **kw: Any,
-    ) -> Optional[Table]:
+    ) -> None:
         """Issue a "create index" instruction using the
         current batch migration context.
 
@@ -998,6 +1016,7 @@ class DropIndexOp(MigrateOperation):
         self,
         index_name: Union[quoted_name, str, conv],
         table_name: Optional[str] = None,
+        *,
         schema: Optional[str] = None,
         _reverse: Optional[CreateIndexOp] = None,
         **kw: Any,
@@ -1019,7 +1038,7 @@ class DropIndexOp(MigrateOperation):
         assert index.table is not None
         return cls(
             index.name,  # type: ignore[arg-type]
-            index.table.name,
+            table_name=index.table.name,
             schema=index.table.schema,
             _reverse=CreateIndexOp.from_index(index),
             **index.kwargs,
@@ -1046,9 +1065,10 @@ class DropIndexOp(MigrateOperation):
         operations: Operations,
         index_name: str,
         table_name: Optional[str] = None,
+        *,
         schema: Optional[str] = None,
         **kw: Any,
-    ) -> Optional[Table]:
+    ) -> None:
         r"""Issue a "drop index" instruction using the current
         migration context.
 
@@ -1076,7 +1096,7 @@ class DropIndexOp(MigrateOperation):
     @classmethod
     def batch_drop_index(
         cls, operations: BatchOperations, index_name: str, **kw: Any
-    ) -> Optional[Table]:
+    ) -> None:
         """Issue a "drop index" instruction using the
         current batch migration context.
 
@@ -1103,6 +1123,7 @@ class CreateTableOp(MigrateOperation):
         self,
         table_name: str,
         columns: Sequence[SchemaItem],
+        *,
         schema: Optional[str] = None,
         _namespace_metadata: Optional[MetaData] = None,
         _constraints_included: bool = False,
@@ -1128,7 +1149,7 @@ class CreateTableOp(MigrateOperation):
 
     @classmethod
     def from_table(
-        cls, table: Table, _namespace_metadata: Optional[MetaData] = None
+        cls, table: Table, *, _namespace_metadata: Optional[MetaData] = None
     ) -> CreateTableOp:
         if _namespace_metadata is None:
             _namespace_metadata = table.metadata
@@ -1174,7 +1195,7 @@ class CreateTableOp(MigrateOperation):
         table_name: str,
         *columns: SchemaItem,
         **kw: Any,
-    ) -> Optional[Table]:
+    ) -> Table:
         r"""Issue a "create table" instruction using the current migration
         context.
 
@@ -1186,11 +1207,11 @@ class CreateTableOp(MigrateOperation):
             from alembic import op
 
             op.create_table(
-                'account',
-                Column('id', INTEGER, primary_key=True),
-                Column('name', VARCHAR(50), nullable=False),
-                Column('description', NVARCHAR(200)),
-                Column('timestamp', TIMESTAMP, server_default=func.now())
+                "account",
+                Column("id", INTEGER, primary_key=True),
+                Column("name", VARCHAR(50), nullable=False),
+                Column("description", NVARCHAR(200)),
+                Column("timestamp", TIMESTAMP, server_default=func.now()),
             )
 
         Note that :meth:`.create_table` accepts
@@ -1204,9 +1225,10 @@ class CreateTableOp(MigrateOperation):
             from sqlalchemy import Column, TIMESTAMP, func
 
             # specify "DEFAULT NOW" along with the "timestamp" column
-            op.create_table('account',
-                Column('id', INTEGER, primary_key=True),
-                Column('timestamp', TIMESTAMP, server_default=func.now())
+            op.create_table(
+                "account",
+                Column("id", INTEGER, primary_key=True),
+                Column("timestamp", TIMESTAMP, server_default=func.now()),
             )
 
         The function also returns a newly created
@@ -1219,11 +1241,11 @@ class CreateTableOp(MigrateOperation):
             from alembic import op
 
             account_table = op.create_table(
-                'account',
-                Column('id', INTEGER, primary_key=True),
-                Column('name', VARCHAR(50), nullable=False),
-                Column('description', NVARCHAR(200)),
-                Column('timestamp', TIMESTAMP, server_default=func.now())
+                "account",
+                Column("id", INTEGER, primary_key=True),
+                Column("name", VARCHAR(50), nullable=False),
+                Column("description", NVARCHAR(200)),
+                Column("timestamp", TIMESTAMP, server_default=func.now()),
             )
 
             op.bulk_insert(
@@ -1231,7 +1253,7 @@ class CreateTableOp(MigrateOperation):
                 [
                     {"name": "A1", "description": "account 1"},
                     {"name": "A2", "description": "account 2"},
-                ]
+                ],
             )
 
         :param table_name: Name of the table
@@ -1262,6 +1284,7 @@ class DropTableOp(MigrateOperation):
     def __init__(
         self,
         table_name: str,
+        *,
         schema: Optional[str] = None,
         table_kw: Optional[MutableMapping[Any, Any]] = None,
         _reverse: Optional[CreateTableOp] = None,
@@ -1282,7 +1305,7 @@ class DropTableOp(MigrateOperation):
 
     @classmethod
     def from_table(
-        cls, table: Table, _namespace_metadata: Optional[MetaData] = None
+        cls, table: Table, *, _namespace_metadata: Optional[MetaData] = None
     ) -> DropTableOp:
         return cls(
             table.name,
@@ -1326,6 +1349,7 @@ class DropTableOp(MigrateOperation):
         cls,
         operations: Operations,
         table_name: str,
+        *,
         schema: Optional[str] = None,
         **kw: Any,
     ) -> None:
@@ -1356,6 +1380,7 @@ class AlterTableOp(MigrateOperation):
     def __init__(
         self,
         table_name: str,
+        *,
         schema: Optional[str] = None,
     ) -> None:
         self.table_name = table_name
@@ -1370,6 +1395,7 @@ class RenameTableOp(AlterTableOp):
         self,
         old_table_name: str,
         new_table_name: str,
+        *,
         schema: Optional[str] = None,
     ) -> None:
         super().__init__(old_table_name, schema=schema)
@@ -1381,8 +1407,9 @@ class RenameTableOp(AlterTableOp):
         operations: Operations,
         old_table_name: str,
         new_table_name: str,
+        *,
         schema: Optional[str] = None,
-    ) -> Optional[Table]:
+    ) -> None:
         """Emit an ALTER TABLE to rename a table.
 
         :param old_table_name: old name.
@@ -1408,6 +1435,7 @@ class CreateTableCommentOp(AlterTableOp):
         self,
         table_name: str,
         comment: Optional[str],
+        *,
         schema: Optional[str] = None,
         existing_comment: Optional[str] = None,
     ) -> None:
@@ -1422,9 +1450,10 @@ class CreateTableCommentOp(AlterTableOp):
         operations: Operations,
         table_name: str,
         comment: Optional[str],
+        *,
         existing_comment: Optional[str] = None,
         schema: Optional[str] = None,
-    ) -> Optional[Table]:
+    ) -> None:
         """Emit a COMMENT ON operation to set the comment for a table.
 
         .. versionadded:: 1.0.6
@@ -1456,10 +1485,11 @@ class CreateTableCommentOp(AlterTableOp):
     @classmethod
     def batch_create_table_comment(
         cls,
-        operations,
-        comment,
-        existing_comment=None,
-    ):
+        operations: BatchOperations,
+        comment: Optional[str],
+        *,
+        existing_comment: Optional[str] = None,
+    ) -> None:
         """Emit a COMMENT ON operation to set the comment for a table
         using the current batch migration context.
 
@@ -1519,6 +1549,7 @@ class DropTableCommentOp(AlterTableOp):
     def __init__(
         self,
         table_name: str,
+        *,
         schema: Optional[str] = None,
         existing_comment: Optional[str] = None,
     ) -> None:
@@ -1531,9 +1562,10 @@ class DropTableCommentOp(AlterTableOp):
         cls,
         operations: Operations,
         table_name: str,
+        *,
         existing_comment: Optional[str] = None,
         schema: Optional[str] = None,
-    ) -> Optional[Table]:
+    ) -> None:
         """Issue a "drop table comment" operation to
         remove an existing comment set on a table.
 
@@ -1555,7 +1587,12 @@ class DropTableCommentOp(AlterTableOp):
         return operations.invoke(op)
 
     @classmethod
-    def batch_drop_table_comment(cls, operations, existing_comment=None):
+    def batch_drop_table_comment(
+        cls,
+        operations: BatchOperations,
+        *,
+        existing_comment: Optional[str] = None,
+    ) -> None:
         """Issue a "drop table comment" operation to
         remove an existing comment set on a table using the current
         batch operations context.
@@ -1598,6 +1635,7 @@ class AlterColumnOp(AlterTableOp):
         self,
         table_name: str,
         column_name: str,
+        *,
         schema: Optional[str] = None,
         existing_type: Optional[Any] = None,
         existing_server_default: Any = False,
@@ -1757,6 +1795,7 @@ class AlterColumnOp(AlterTableOp):
         operations: Operations,
         table_name: str,
         column_name: str,
+        *,
         nullable: Optional[bool] = None,
         comment: Optional[Union[str, Literal[False]]] = False,
         server_default: Any = False,
@@ -1770,7 +1809,7 @@ class AlterColumnOp(AlterTableOp):
         existing_comment: Optional[str] = None,
         schema: Optional[str] = None,
         **kw: Any,
-    ) -> Optional[Table]:
+    ) -> None:
         r"""Issue an "alter column" instruction using the
         current migration context.
 
@@ -1883,19 +1922,22 @@ class AlterColumnOp(AlterTableOp):
         cls,
         operations: BatchOperations,
         column_name: str,
+        *,
         nullable: Optional[bool] = None,
-        comment: Union[str, Literal[False]] = False,
-        server_default: Union[Function[Any], bool] = False,
+        comment: Optional[Union[str, Literal[False]]] = False,
+        server_default: Any = False,
         new_column_name: Optional[str] = None,
         type_: Optional[Union[TypeEngine, Type[TypeEngine]]] = None,
         existing_type: Optional[Union[TypeEngine, Type[TypeEngine]]] = None,
-        existing_server_default: bool = False,
-        existing_nullable: None = None,
-        existing_comment: None = None,
-        insert_before: None = None,
-        insert_after: None = None,
+        existing_server_default: Optional[
+            Union[str, bool, Identity, Computed]
+        ] = False,
+        existing_nullable: Optional[bool] = None,
+        existing_comment: Optional[str] = None,
+        insert_before: Optional[str] = None,
+        insert_after: Optional[str] = None,
         **kw: Any,
-    ) -> Optional[Table]:
+    ) -> None:
         """Issue an "alter column" instruction using the current
         batch migration context.
 
@@ -1935,6 +1977,8 @@ class AlterColumnOp(AlterTableOp):
             modify_server_default=server_default,
             modify_nullable=nullable,
             modify_comment=comment,
+            insert_before=insert_before,
+            insert_after=insert_after,
             **kw,
         )
 
@@ -1949,7 +1993,8 @@ class AddColumnOp(AlterTableOp):
     def __init__(
         self,
         table_name: str,
-        column: Column,
+        column: Column[Any],
+        *,
         schema: Optional[str] = None,
         **kw: Any,
     ) -> None:
@@ -1964,7 +2009,7 @@ class AddColumnOp(AlterTableOp):
 
     def to_diff_tuple(
         self,
-    ) -> Tuple[str, Optional[str], str, Column]:
+    ) -> Tuple[str, Optional[str], str, Column[Any]]:
         return ("add_column", self.schema, self.table_name, self.column)
 
     def to_column(self) -> Column:
@@ -1979,7 +2024,7 @@ class AddColumnOp(AlterTableOp):
         cls,
         schema: Optional[str],
         tname: str,
-        col: Column,
+        col: Column[Any],
     ) -> AddColumnOp:
         return cls(tname, col, schema=schema)
 
@@ -1988,9 +2033,10 @@ class AddColumnOp(AlterTableOp):
         cls,
         operations: Operations,
         table_name: str,
-        column: Column,
+        column: Column[Any],
+        *,
         schema: Optional[str] = None,
-    ) -> Optional[Table]:
+    ) -> None:
         """Issue an "add column" instruction using the current
         migration context.
 
@@ -1999,35 +2045,64 @@ class AddColumnOp(AlterTableOp):
             from alembic import op
             from sqlalchemy import Column, String
 
-            op.add_column('organization',
-                Column('name', String())
-            )
+            op.add_column("organization", Column("name", String()))
 
-        The provided :class:`~sqlalchemy.schema.Column` object can also
-        specify a :class:`~sqlalchemy.schema.ForeignKey`, referencing
-        a remote table name.  Alembic will automatically generate a stub
-        "referenced" table and emit a second ALTER statement in order
-        to add the constraint separately::
+        The :meth:`.Operations.add_column` method typically corresponds
+        to the SQL command "ALTER TABLE... ADD COLUMN".    Within the scope
+        of this command, the column's name, datatype, nullability,
+        and optional server-generated defaults may be indicated.
+
+        .. note::
+
+            With the exception of NOT NULL constraints or single-column FOREIGN
+            KEY constraints, other kinds of constraints such as PRIMARY KEY,
+            UNIQUE or CHECK constraints **cannot** be generated using this
+            method; for these constraints, refer to operations such as
+            :meth:`.Operations.create_primary_key` and
+            :meth:`.Operations.create_check_constraint`. In particular, the
+            following :class:`~sqlalchemy.schema.Column` parameters are
+            **ignored**:
+
+            * :paramref:`~sqlalchemy.schema.Column.primary_key` - SQL databases
+              typically do not support an ALTER operation that can add
+              individual columns one at a time to an existing primary key
+              constraint, therefore it's less ambiguous to use the
+              :meth:`.Operations.create_primary_key` method, which assumes no
+              existing primary key constraint is present.
+            * :paramref:`~sqlalchemy.schema.Column.unique` - use the
+              :meth:`.Operations.create_unique_constraint` method
+            * :paramref:`~sqlalchemy.schema.Column.index` - use the
+              :meth:`.Operations.create_index` method
+
+
+        The provided :class:`~sqlalchemy.schema.Column` object may include a
+        :class:`~sqlalchemy.schema.ForeignKey` constraint directive,
+        referencing a remote table name. For this specific type of constraint,
+        Alembic will automatically emit a second ALTER statement in order to
+        add the single-column FOREIGN KEY constraint separately::
 
             from alembic import op
             from sqlalchemy import Column, INTEGER, ForeignKey
 
-            op.add_column('organization',
-                Column('account_id', INTEGER, ForeignKey('accounts.id'))
+            op.add_column(
+                "organization",
+                Column("account_id", INTEGER, ForeignKey("accounts.id")),
             )
 
-        Note that this statement uses the :class:`~sqlalchemy.schema.Column`
-        construct as is from the SQLAlchemy library.  In particular,
-        default values to be created on the database side are
-        specified using the ``server_default`` parameter, and not
-        ``default`` which only specifies Python-side defaults::
+        The column argument passed to :meth:`.Operations.add_column` is a
+        :class:`~sqlalchemy.schema.Column` construct, used in the same way it's
+        used in SQLAlchemy. In particular, values or functions to be indicated
+        as producing the column's default value on the database side are
+        specified using the ``server_default`` parameter, and not ``default``
+        which only specifies Python-side defaults::
 
             from alembic import op
             from sqlalchemy import Column, TIMESTAMP, func
 
             # specify "DEFAULT NOW" along with the column add
-            op.add_column('account',
-                Column('timestamp', TIMESTAMP, server_default=func.now())
+            op.add_column(
+                "account",
+                Column("timestamp", TIMESTAMP, server_default=func.now()),
             )
 
         :param table_name: String name of the parent table.
@@ -2047,10 +2122,11 @@ class AddColumnOp(AlterTableOp):
     def batch_add_column(
         cls,
         operations: BatchOperations,
-        column: Column,
+        column: Column[Any],
+        *,
         insert_before: Optional[str] = None,
         insert_after: Optional[str] = None,
-    ) -> Optional[Table]:
+    ) -> None:
         """Issue an "add column" instruction using the current
         batch migration context.
 
@@ -2084,6 +2160,7 @@ class DropColumnOp(AlterTableOp):
         self,
         table_name: str,
         column_name: str,
+        *,
         schema: Optional[str] = None,
         _reverse: Optional[AddColumnOp] = None,
         **kw: Any,
@@ -2095,7 +2172,7 @@ class DropColumnOp(AlterTableOp):
 
     def to_diff_tuple(
         self,
-    ) -> Tuple[str, Optional[str], str, Column]:
+    ) -> Tuple[str, Optional[str], str, Column[Any]]:
         return (
             "remove_column",
             self.schema,
@@ -2119,7 +2196,7 @@ class DropColumnOp(AlterTableOp):
         cls,
         schema: Optional[str],
         tname: str,
-        col: Column,
+        col: Column[Any],
     ) -> DropColumnOp:
         return cls(
             tname,
@@ -2142,15 +2219,16 @@ class DropColumnOp(AlterTableOp):
         operations: Operations,
         table_name: str,
         column_name: str,
+        *,
         schema: Optional[str] = None,
         **kw: Any,
-    ) -> Optional[Table]:
+    ) -> None:
         """Issue a "drop column" instruction using the current
         migration context.
 
         e.g.::
 
-            drop_column('organization', 'account_id')
+            drop_column("organization", "account_id")
 
         :param table_name: name of table
         :param column_name: name of column
@@ -2188,7 +2266,7 @@ class DropColumnOp(AlterTableOp):
     @classmethod
     def batch_drop_column(
         cls, operations: BatchOperations, column_name: str, **kw: Any
-    ) -> Optional[Table]:
+    ) -> None:
         """Issue a "drop column" instruction using the current
         batch migration context.
 
@@ -2214,6 +2292,7 @@ class BulkInsertOp(MigrateOperation):
         self,
         table: Union[Table, TableClause],
         rows: List[dict],
+        *,
         multiinsert: bool = True,
     ) -> None:
         self.table = table
@@ -2226,6 +2305,7 @@ class BulkInsertOp(MigrateOperation):
         operations: Operations,
         table: Union[Table, TableClause],
         rows: List[dict],
+        *,
         multiinsert: bool = True,
     ) -> None:
         """Issue a "bulk insert" operation using the current
@@ -2245,37 +2325,58 @@ class BulkInsertOp(MigrateOperation):
             from sqlalchemy import String, Integer, Date
 
             # Create an ad-hoc table to use for the insert statement.
-            accounts_table = table('account',
-                column('id', Integer),
-                column('name', String),
-                column('create_date', Date)
+            accounts_table = table(
+                "account",
+                column("id", Integer),
+                column("name", String),
+                column("create_date", Date),
             )
 
-            op.bulk_insert(accounts_table,
+            op.bulk_insert(
+                accounts_table,
                 [
-                    {'id':1, 'name':'John Smith',
-                            'create_date':date(2010, 10, 5)},
-                    {'id':2, 'name':'Ed Williams',
-                            'create_date':date(2007, 5, 27)},
-                    {'id':3, 'name':'Wendy Jones',
-                            'create_date':date(2008, 8, 15)},
-                ]
+                    {
+                        "id": 1,
+                        "name": "John Smith",
+                        "create_date": date(2010, 10, 5),
+                    },
+                    {
+                        "id": 2,
+                        "name": "Ed Williams",
+                        "create_date": date(2007, 5, 27),
+                    },
+                    {
+                        "id": 3,
+                        "name": "Wendy Jones",
+                        "create_date": date(2008, 8, 15),
+                    },
+                ],
             )
 
         When using --sql mode, some datatypes may not render inline
         automatically, such as dates and other special types.   When this
         issue is present, :meth:`.Operations.inline_literal` may be used::
 
-            op.bulk_insert(accounts_table,
+            op.bulk_insert(
+                accounts_table,
                 [
-                    {'id':1, 'name':'John Smith',
-                            'create_date':op.inline_literal("2010-10-05")},
-                    {'id':2, 'name':'Ed Williams',
-                            'create_date':op.inline_literal("2007-05-27")},
-                    {'id':3, 'name':'Wendy Jones',
-                            'create_date':op.inline_literal("2008-08-15")},
+                    {
+                        "id": 1,
+                        "name": "John Smith",
+                        "create_date": op.inline_literal("2010-10-05"),
+                    },
+                    {
+                        "id": 2,
+                        "name": "Ed Williams",
+                        "create_date": op.inline_literal("2007-05-27"),
+                    },
+                    {
+                        "id": 3,
+                        "name": "Wendy Jones",
+                        "create_date": op.inline_literal("2008-08-15"),
+                    },
                 ],
-                multiinsert=False
+                multiinsert=False,
             )
 
         When using :meth:`.Operations.inline_literal` in conjunction with
@@ -2308,13 +2409,15 @@ class BulkInsertOp(MigrateOperation):
 
 
 @Operations.register_operation("execute")
+@BatchOperations.register_operation("execute", "batch_execute")
 class ExecuteSQLOp(MigrateOperation):
     """Represent an execute SQL operation."""
 
     def __init__(
         self,
         sqltext: Union[Update, str, Insert, TextClause],
-        execution_options: None = None,
+        *,
+        execution_options: Optional[dict[str, Any]] = None,
     ) -> None:
         self.sqltext = sqltext
         self.execution_options = execution_options
@@ -2324,8 +2427,9 @@ class ExecuteSQLOp(MigrateOperation):
         cls,
         operations: Operations,
         sqltext: Union[str, TextClause, Update],
-        execution_options: None = None,
-    ) -> Optional[Table]:
+        *,
+        execution_options: Optional[dict[str, Any]] = None,
+    ) -> None:
         r"""Execute the given SQL using the current migration context.
 
         The given SQL can be a plain string, e.g.::
@@ -2394,8 +2498,8 @@ class ExecuteSQLOp(MigrateOperation):
         * a :func:`sqlalchemy.sql.expression.update`,
           :func:`sqlalchemy.sql.expression.insert`,
           or :func:`sqlalchemy.sql.expression.delete`  construct.
-        * Pretty much anything that's "executable" as described
-          in :ref:`sqlexpression_toplevel`.
+        * Any "executable" described in SQLAlchemy Core documentation,
+          noting that no result set is returned.
 
         .. note::  when passing a plain string, the statement is coerced into
            a :func:`sqlalchemy.sql.expression.text` construct. This construct
@@ -2410,6 +2514,25 @@ class ExecuteSQLOp(MigrateOperation):
         op = cls(sqltext, execution_options=execution_options)
         return operations.invoke(op)
 
+    @classmethod
+    def batch_execute(
+        cls,
+        operations: Operations,
+        sqltext: Union[str, TextClause, Update],
+        *,
+        execution_options: Optional[dict[str, Any]] = None,
+    ) -> None:
+        """Execute the given SQL using the current migration context.
+
+        .. seealso::
+
+            :meth:`.Operations.execute`
+
+        """
+        return cls.execute(
+            operations, sqltext, execution_options=execution_options
+        )
+
 
 class OpContainer(MigrateOperation):
     """Represent a sequence of operations operation."""
@@ -2441,6 +2564,7 @@ class ModifyTableOps(OpContainer):
         self,
         table_name: str,
         ops: Sequence[MigrateOperation],
+        *,
         schema: Optional[str] = None,
     ) -> None:
         super().__init__(ops)
@@ -2538,6 +2662,7 @@ class MigrationScript(MigrateOperation):
         rev_id: Optional[str],
         upgrade_ops: UpgradeOps,
         downgrade_ops: DowngradeOps,
+        *,
         message: Optional[str] = None,
         imports: Set[str] = set(),
         head: Optional[str] = None,
