@@ -46,7 +46,7 @@ if TYPE_CHECKING:
     from sqlalchemy.sql.selectable import Select
     from sqlalchemy.sql.selectable import TableClause
 
-_CE = TypeVar("_CE", bound=Union["ColumnElement", "SchemaItem"])
+_CE = TypeVar("_CE", bound=Union["ColumnElement[Any]", "SchemaItem"])
 
 
 def _safe_int(value: str) -> Union[int, str]:
@@ -61,6 +61,8 @@ _vers = tuple(
 )
 sqla_13 = _vers >= (1, 3)
 sqla_14 = _vers >= (1, 4)
+# https://docs.sqlalchemy.org/en/latest/changelog/changelog_14.html#change-0c6e0cc67dfe6fac5164720e57ef307d
+sqla_14_18 = _vers >= (1, 4, 18)
 sqla_14_26 = _vers >= (1, 4, 26)
 sqla_2 = _vers >= (2,)
 sqlalchemy_version = __version__
@@ -71,18 +73,17 @@ except ImportError:
     from sqlalchemy.sql.elements import _NONE_NAME as _NONE_NAME  # type: ignore  # noqa: E501
 
 
-if sqla_14:
-    # when future engine merges, this can be again based on version string
-    from sqlalchemy.engine import Connection as legacy_connection
+class _Unsupported:
+    "Placeholder for unsupported SQLAlchemy classes"
 
-    sqla_1x = not hasattr(legacy_connection, "commit")
-else:
-    sqla_1x = True
 
 try:
-    from sqlalchemy import Computed  # noqa
+    from sqlalchemy import Computed
 except ImportError:
-    Computed = type(None)  # type: ignore
+
+    class Computed(_Unsupported):  # type: ignore
+        pass
+
     has_computed = False
     has_computed_reflection = False
 else:
@@ -90,12 +91,15 @@ else:
     has_computed_reflection = _vers >= (1, 3, 16)
 
 try:
-    from sqlalchemy import Identity  # noqa
+    from sqlalchemy import Identity
 except ImportError:
-    Identity = type(None)  # type: ignore
+
+    class Identity(_Unsupported):  # type: ignore
+        pass
+
     has_identity = False
 else:
-    # attributes common to Indentity and Sequence
+    # attributes common to Identity and Sequence
     _identity_options_attrs = (
         "start",
         "increment",
@@ -107,7 +111,7 @@ else:
         "cache",
         "order",
     )
-    # attributes of Indentity
+    # attributes of Identity
     _identity_attrs = _identity_options_attrs + ("on_null",)
     has_identity = True
 
@@ -299,9 +303,7 @@ def _columns_for_constraint(constraint):
         return list(constraint.columns)
 
 
-def _reflect_table(
-    inspector: Inspector, table: Table, include_cols: None
-) -> None:
+def _reflect_table(inspector: Inspector, table: Table) -> None:
     if sqla_14:
         return inspector.reflect_table(table, None)
     else:
@@ -388,7 +390,7 @@ def _find_columns(clause):
 
 
 def _remove_column_from_collection(
-    collection: ColumnCollection, column: Union[Column, ColumnClause]
+    collection: ColumnCollection, column: Union[Column[Any], ColumnClause[Any]]
 ) -> None:
     """remove a column from a ColumnCollection."""
 
@@ -406,8 +408,8 @@ def _remove_column_from_collection(
 
 
 def _textual_index_column(
-    table: Table, text_: Union[str, TextClause, ColumnElement]
-) -> Union[ColumnElement, Column]:
+    table: Table, text_: Union[str, TextClause, ColumnElement[Any]]
+) -> Union[ColumnElement[Any], Column[Any]]:
     """a workaround for the Index construct's severe lack of flexibility"""
     if isinstance(text_, str):
         c = Column(text_, sqltypes.NULLTYPE)
