@@ -1636,6 +1636,34 @@ class AutogenRenderTest(TestBase):
             "sa.ARRAY(sa.DateTime(timezone=True))",
         )
 
+    @config.combinations(None, "default", "my_module.")
+    def test_render_create_table_with_user_module_type(self, mod):
+        class MyType(UserDefinedType):
+            def get_col_spec(self):
+                return "MYTYPE"
+
+        type_ = MyType()
+        uo = ops.UpgradeOps(
+            ops=[ops.CreateTableOp("sometable", [Column("x", type_)])]
+        )
+        if mod != "default":
+            kw = {"user_module_prefix": mod}
+        else:
+            kw = {}
+        if mod and mod != "default":
+            prefix = mod
+        else:
+            prefix = f"{__name__}."
+
+        eq_(
+            autogenerate.render_python_code(uo, **kw),
+            "# ### commands auto generated by Alembic - please adjust! ###\n"
+            "    op.create_table('sometable',\n"
+            f"    sa.Column('x', {prefix}MyType(), nullable=True)\n"
+            "    )\n"
+            "    # ### end Alembic commands ###",
+        )
+
     def test_render_array_no_context(self):
         uo = ops.UpgradeOps(
             ops=[
