@@ -122,9 +122,17 @@ class PostgresqlOpTest(TestBase):
         op.create_index("i", "t", ["c1", "c2"], unique=False)
         context.assert_("CREATE INDEX i ON t (c1, c2)")
 
-    def test_drop_index_postgresql_concurrently(self):
+    @config.combinations("include_table", "no_table", argnames="include_table")
+    def test_drop_index_postgresql_concurrently(self, include_table):
         context = op_fixture("postgresql")
-        op.drop_index("geocoded", "locations", postgresql_concurrently=True)
+        if include_table == "include_table":
+            op.drop_index(
+                "geocoded",
+                table_name="locations",
+                postgresql_concurrently=True,
+            )
+        else:
+            op.drop_index("geocoded", postgresql_concurrently=True)
         context.assert_("DROP INDEX CONCURRENTLY geocoded")
 
     def test_alter_column_type_using(self):
@@ -846,7 +854,7 @@ class PostgresqlDetectSerialTest(TestBase):
 
         eq_(
             _render_server_default_for_compare(
-                tab.c.x.server_default, tab.c.x, self.autogen_context
+                tab.c.x.server_default, self.autogen_context
             ),
             c_expected,
         )
@@ -867,7 +875,7 @@ class PostgresqlDetectSerialTest(TestBase):
         server_default = diffs[0][0][4]["existing_server_default"]
         eq_(
             _render_server_default_for_compare(
-                server_default, tab.c.x, self.autogen_context
+                server_default, self.autogen_context
             ),
             c_expected,
         )
@@ -1053,8 +1061,6 @@ class PostgresqlAutogenRenderTest(TestBase):
         )
 
     def test_add_exclude_constraint(self):
-        from sqlalchemy.dialects.postgresql import ExcludeConstraint
-
         autogen_context = self.autogen_context
 
         m = MetaData()
@@ -1074,8 +1080,6 @@ class PostgresqlAutogenRenderTest(TestBase):
         )
 
     def test_add_exclude_constraint_case_sensitive(self):
-        from sqlalchemy.dialects.postgresql import ExcludeConstraint
-
         autogen_context = self.autogen_context
 
         m = MetaData()
@@ -1100,8 +1104,6 @@ class PostgresqlAutogenRenderTest(TestBase):
         )
 
     def test_inline_exclude_constraint(self):
-        from sqlalchemy.dialects.postgresql import ExcludeConstraint
-
         autogen_context = self.autogen_context
 
         m = MetaData()
@@ -1130,8 +1132,6 @@ class PostgresqlAutogenRenderTest(TestBase):
         )
 
     def test_inline_exclude_constraint_case_sensitive(self):
-        from sqlalchemy.dialects.postgresql import ExcludeConstraint
-
         autogen_context = self.autogen_context
 
         m = MetaData()
@@ -1183,6 +1183,39 @@ class PostgresqlAutogenRenderTest(TestBase):
             "name='TExclID'))",
         )
 
+    @config.requirements.sqlalchemy_2
+    def test_inline_exclude_constraint_fn(self):
+        """test for #1230"""
+
+        autogen_context = self.autogen_context
+
+        effective_time = Column("effective_time", DateTime(timezone=True))
+        expiry_time = Column("expiry_time", DateTime(timezone=True))
+
+        m = MetaData()
+        t = Table(
+            "TTable",
+            m,
+            effective_time,
+            expiry_time,
+            ExcludeConstraint(
+                (func.tstzrange(effective_time, expiry_time), "&&"),
+                using="gist",
+            ),
+        )
+
+        op_obj = ops.CreateTableOp.from_table(t)
+
+        eq_ignore_whitespace(
+            autogenerate.render_op_text(autogen_context, op_obj),
+            "op.create_table('TTable',sa.Column('effective_time', "
+            "sa.DateTime(timezone=True), nullable=True),"
+            "sa.Column('expiry_time', sa.DateTime(timezone=True), "
+            "nullable=True),postgresql.ExcludeConstraint("
+            "(sa.text('tstzrange(effective_time, expiry_time)'), "
+            "'&&'), using='gist'))",
+        )
+
     @config.requirements.sqlalchemy_2
     def test_inline_exclude_constraint_text(self):
         """test for #1184.
